@@ -1,6 +1,6 @@
 from extras.plugins import PluginConfig
 
-__version__ = "0.0.0.0.91"
+__version__ = "0.0.0.0.110"
 
 
 class OCPProjectConfig(PluginConfig):
@@ -20,6 +20,22 @@ class OCPProjectConfig(PluginConfig):
         'ocp_dev_url',
         'ocp_int_url',
         'ocp_prd_url',
+        'argocd_tst_url',
+        'argocd_dev_url',
+        'argocd_int_url',
+        'argocd_prd_url',
+        'prometheus_tst_url',
+        'prometheus_dev_url',
+        'prometheus_int_url',
+        'prometheus_prd_url',
+        'grafana_tst_url',
+        'grafana_dev_url',
+        'grafana_int_url',
+        'grafana_prd_url',
+        'kibana_tst_url',
+        'kibana_dev_url',
+        'kibana_int_url',
+        'kibana_prd_url',
         'cpu_cost',
         'memory_cost',
         'storage_cost'
