@@ -1,3 +1,5 @@
+import logging
+
 from django_rq import job, get_queue
 from dcim.models import Device
 #from ocp_project_plugin.models import AppEnvironment, OCPProject, Collection, Compliance, ServiceMapping
@@ -21,19 +23,9 @@ import yaml
 from yaml import SafeLoader
 from collections import namedtuple
 
-PLUGIN_SETTINGS = settings.PLUGINS_CONFIG.get("config_officer", dict())
-CF_NAME_COLLECTION_STATUS = PLUGIN_SETTINGS.get("CF_NAME_COLLECTION_STATUS", "collection_status")
-NETBOX_DEVICES_CONFIGS_DIR = PLUGIN_SETTINGS.get("NETBOX_DEVICES_CONFIGS_DIR", "/device_configs")
-GLOBAL_TASK_INIT_MESSAGE = 'global_collection_task'
-
 PLUGIN_SETTINGS = settings.PLUGINS_CONFIG.get('ocp_project_plugin', dict())
 GITLAB_PROJECT_URL = PLUGIN_SETTINGS.get('gitlab_project_url', '')
-VALUES_PATH = PLUGIN_SETTINGS.get('values_path', '')
-    #""" Get count of pending collection tasks."""
-    #return Collection.objects.filter((Q(status__iexact=CollectStatusChoices.STATUS_PENDING)
-    #                                  | Q(status__iexact=CollectStatusChoices.STATUS_RUNNING)) & Q(
-    #    message__iexact=GLOBAL_TASK_INIT_MESSAGE)).count()
-
+VALUES_PATH = PLUGIN_SETTINGS.get('jira_browse_url', '')
 
 """
 1. Git Repo pullen
@@ -48,26 +40,17 @@ VALUES_PATH = PLUGIN_SETTINGS.get('values_path', '')
 """
 
 
-@job("default")
-def pull_repository_2(hostname):
-    """Collect device configuration by name. Task started with hostname param.
-
-    device = Device.objects.get(name__iexact=hostname)
-    collect_task = Collection.objects.create(device=device, message="device collection task")
-    collect_task.save()
-"""
-    now = datetime.now().strftime("%Y_%m_%d_%H_%M_%S")
-    commit_msg = f"device_{hostname}_{now}"
-    #get_queue("default").enqueue("ocp_project_plugin.worker.pull_repository", collect_task.pk, commit_msg)
-
-
 @job("default")
 def pull_repository():
     g = git.cmd.Git('/repo/project_repo')
     result = g.pull()
-    print(f'{result}')
+    print(f'{g.working_dir}-{result}')
 
 
 @job("default")
 def clone_repository():
-    Repo.clone_from(GITLAB_PROJECT_URL, '/repo/project_repo')
+    logger = logging.getLogger('netbox.ocp_project_plugin')
+    logger.warning(f'Started cloning')
+    logger.warning(f'{GITLAB_PROJECT_URL}')
+    git.Git('/repo/').clone(GITLAB_PROJECT_URL)
+    logger.warning(f'cloning finished')
